@@ -1,7 +1,7 @@
 """Signals"""
 from django.dispatch import Signal
 
-# Pre save signal
+# Pre update signal
 #   This signal is sent when user instance is about to be updated with
 #   new values from services provided. This way custom actions can be
 #   attached and values updated if needed before the saving time.
@@ -16,3 +16,7 @@ from django.dispatch import Signal
 #       response: Raw auth service response
 #       details:  Processed details values (basic fields)
 pre_update = Signal(providing_args=['user', 'response', 'details'])
+
+socialauth_registered = Signal(providing_args=['user', 'response', 'details'])
+
+socialauth_not_registered = Signal(providing_args=['uid', 'response', 'details'])
